==> istio-model-v1beta1-6.6.1-sources.jar: io/fabric8/istio/api/security/v1beta1/OperationFluent.java <==
package io.fabric8.istio.api.security.v1beta1;

import java.lang.Integer;
import io.fabric8.kubernetes.api.builder.Fluent;
import java.util.ArrayList;
import java.util.Collection;
import java.util.List;
import java.lang.String;
import java.lang.Boolean;
import java.util.function.Predicate;

 /**
  * Generated
  */
public interface OperationFluent<A extends OperationFluent<A>> extends Fluent<A>{
  public A addToHosts(Integer index,String item);
  public A setToHosts(Integer index,String item);
  public A addToHosts(java.lang.String... items);
  public A addAllToHosts(Collection<String> items);
  public A removeFromHosts(java.lang.String... items);
  public A removeAllFromHosts(Collection<String> items);
  public List<String> getHosts();
  public String getHost(Integer index);
  public String getFirstHost();
  public String getLastHost();
  public String getMatchingHost(Predicate<String> predicate);
  public Boolean hasMatchingHost(Predicate<String> predicate);
  public A withHosts(List<String> hosts);
  public A withHosts(java.lang.String... hosts);
  public Boolean hasHosts();
  public A addToMethods(Integer index,String item);
  public A setToMethods(Integer index,String item);
  public A addToMethods(java.lang.String... items);
  public A addAllToMethods(Collection<String> items);
  public A removeFromMethods(java.lang.String... items);
  public A removeAllFromMethods(Collection<String> items);
  public List<String> getMethods();
  public String getMethod(Integer index);
  public String getFirstMethod();
  public String getLastMethod();
  public String getMatchingMethod(Predicate<String> predicate);
  public Boolean hasMatchingMethod(Predicate<String> predicate);
  public A withMethods(List<String> methods);
  public A withMethods(java.lang.String... methods);
  public Boolean hasMethods();
  public A addToNotHosts(Integer index,String item);
  public A setToNotHosts(Integer index,String item);
  public A addToNotHosts(java.lang.String... items);
  public A addAllToNotHosts(Collection<String> items);
  public A removeFromNotHosts(java.lang.String... items);
  public A removeAllFromNotHosts(Collection<String> items);
  public List<String> getNotHosts();
  public String getNotHost(Integer index);
  public String getFirstNotHost();
  public String getLastNotHost();
  public String getMatchingNotHost(Predicate<String> predicate);
  public Boolean hasMatchingNotHost(Predicate<String> predicate);
  public A withNotHosts(List<String> notHosts);
  public A withNotHosts(java.lang.String... notHosts);
  public Boolean hasNotHosts();
  public A addToNotMethods(Integer index,String item);
  public A setToNotMethods(Integer index,String item);
  public A addToNotMethods(java.lang.String... items);
  public A addAllToNotMethods(Collection<String> items);
  public A removeFromNotMethods(java.lang.String... items);
  public A removeAllFromNotMethods(Collection<String> items);
  public List<String> getNotMethods();
  public String getNotMethod(Integer index);
  public String getFirstNotMethod();
  public String getLastNotMethod();
  public String getMatchingNotMethod(Predicate<String> predicate);
  public Boolean hasMatchingNotMethod(Predicate<String> predicate);
  public A withNotMethods(List<String> notMethods);
  public A withNotMethods(java.lang.String... notMethods);
  public Boolean hasNotMethods();
  public A addToNotPaths(Integer index,String item);
  public A setToNotPaths(Integer index,String item);
  public A addToNotPaths(java.lang.String... items);
  public A addAllToNotPaths(Collection<String> items);
  public A removeFromNotPaths(java.lang.String... items);
  public A removeAllFromNotPaths(Collection<String> items);
  public List<String> getNotPaths();
  public String getNotPath(Integer index);
  public String getFirstNotPath();
  public String getLastNotPath();
  public String getMatchingNotPath(Predicate<String> predicate);
  public Boolean hasMatchingNotPath(Predicate<String> predicate);
  public A withNotPaths(List<String> notPaths);
  public A withNotPaths(java.lang.String... notPaths);
  public Boolean hasNotPaths();
  public A addToNotPorts(Integer index,String item);
  public A setToNotPorts(Integer index,String item);
  public A addToNotPorts(java.lang.String... items);
  public A addAllToNotPorts(Collection<String> items);
  public A removeFromNotPorts(java.lang.String... items);
  public A removeAllFromNotPorts(Collection<String> items);
  public List<String> getNotPorts();
  public String getNotPort(Integer index);
  public String getFirstNotPort();
  public String getLastNotPort();
  public String getMatchingNotPort(Predicate<String> predicate);
  public Boolean hasMatchingNotPort(Predicate<String> predicate);
  public A withNotPorts(List<String> notPorts);
  public A withNotPorts(java.lang.String... notPorts);
  public Boolean hasNotPorts();
  public A addToPaths(Integer index,String item);
  public A setToPaths(Integer index,String item);
  public A addToPaths(java.lang.String... items);
  public A addAllToPaths(Collection<String> items);
  public A removeFromPaths(java.lang.String... items);
  public A removeAllFromPaths(Collection<String> items);
  public List<String> getPaths();
  public String getPath(Integer index);
  public String getFirstPath();
  public String getLastPath();
  public String getMatchingPath(Predicate<String> predicate);
  public Boolean hasMatchingPath(Predicate<String> predicate);
  public A withPaths(List<String> paths);
  public A withPaths(java.lang.String... paths);
  public Boolean hasPaths();
  public A addToPorts(Integer index,String item);
  public A setToPorts(Integer index,String item);
  public A addToPorts(java.lang.String... items);
  public A addAllToPorts(Collection<String> items);
  public A removeFromPorts(java.lang.String... items);
  public A removeAllFromPorts(Collection<String> items);
  public List<String> getPorts();
  public String getPort(Integer index);
  public String getFirstPort();
  public String getLastPort();
  public String getMatchingPort(Predicate<String> predicate);
  public Boolean hasMatchingPort(Predicate<String> predicate);
  public A withPorts(List<String> ports);
  public A withPorts(java.lang.String... ports);
  public Boolean hasPorts();
  
}

==> istio-model-v1beta1-6.7.1-sources.jar: io/fabric8/istio/api/security/v1beta1/OperationFluent.java <==
package io.fabric8.istio.api.security.v1beta1;

import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import com.fasterxml.jackson.annotation.JsonInclude;
import java.util.ArrayList;
import java.util.Collection;
import java.util.List;
import java.lang.String;
import java.lang.Boolean;
import java.util.function.Predicate;

 /**
  * Generated
  */
public interface OperationFluent<A extends OperationFluent<A>> extends Fluent<A>{
  public A addToHosts(int index,String item);
  public A setToHosts(int index,String item);
  public A addToHosts(java.lang.String... items);
  public A addAllToHosts(Collection<String> items);
  public A removeFromHosts(java.lang.String... items);
  public A removeAllFromHosts(Collection<String> items);
  public List<String> getHosts();
  public String getHost(int index);
  public String getFirstHost();
  public String getLastHost();
  public String getMatchingHost(Predicate<String> predicate);
  public Boolean hasMatchingHost(Predicate<String> predicate);
  public A withHosts(List<String> hosts);
  public A withHosts(java.lang.String... hosts);
  public Boolean hasHosts();
  public A addToMethods(int index,String item);
  public A setToMethods(int index,String item);
  public A addToMethods(java.lang.String... items);
  public A addAllToMethods(Collection<String> items);
  public A removeFromMethods(java.lang.String... items);
  public A removeAllFromMethods(Collection<String> items);
  public List<String> getMethods();
  public String getMethod(int index);
  public String getFirstMethod();
  public String getLastMethod();
  public String getMatchingMethod(Predicate<String> predicate);
  public Boolean hasMatchingMethod(Predicate<String> predicate);
  public A withMethods(List<String> methods);
  public A withMethods(java.lang.String... methods);
  public Boolean hasMethods();
  public A addToNotHosts(int index,String item);
  public A setToNotHosts(int index,String item);
  public A addToNotHosts(java.lang.String... items);
  public A addAllToNotHosts(Collection<String> items);
  public A removeFromNotHosts(java.lang.String... items);
  public A removeAllFromNotHosts(Collection<String> items);
  public List<String> getNotHosts();
  public String getNotHost(int index);
  public String getFirstNotHost();
  public String getLastNotHost();
  public String getMatchingNotHost(Predicate<String> predicate);
  public Boolean hasMatchingNotHost(Predicate<String> predicate);
  public A withNotHosts(List<String> notHosts);
  public A withNotHosts(java.lang.String... notHosts);
  public Boolean hasNotHosts();
  public A addToNotMethods(int index,String item);
  public A setToNotMethods(int index,String item);
  public A addToNotMethods(java.lang.String... items);
  public A addAllToNotMethods(Collection<String> items);
  public A removeFromNotMethods(java.lang.String... items);
  public A removeAllFromNotMethods(Collection<String> items);
  public List<String> getNotMethods();
  public String getNotMethod(int index);
  public String getFirstNotMethod();
  public String getLastNotMethod();
  public String getMatchingNotMethod(Predicate<String> predicate);
  public Boolean hasMatchingNotMethod(Predicate<String> predicate);
  public A withNotMethods(List<String> notMethods);
  public A withNotMethods(java.lang.String... notMethods);
  public Boolean hasNotMethods();
  public A addToNotPaths(int index,String item);
  public A setToNotPaths(int index,String item);
  public A addToNotPaths(java.lang.String... items);
  public A addAllToNotPaths(Collection<String> items);
  public A removeFromNotPaths(java.lang.String... items);
  public A removeAllFromNotPaths(Collection<String> items);
  public List<String> getNotPaths();
  public String getNotPath(int index);
  public String getFirstNotPath();
  public String getLastNotPath();
  public String getMatchingNotPath(Predicate<String> predicate);
  public Boolean hasMatchingNotPath(Predicate<String> predicate);
  public A withNotPaths(List<String> notPaths);
  public A withNotPaths(java.lang.String... notPaths);
  public Boolean hasNotPaths();
  public A addToNotPorts(int index,String item);
  public A setToNotPorts(int index,String item);
  public A addToNotPorts(java.lang.String... items);
  public A addAllToNotPorts(Collection<String> items);
  public A removeFromNotPorts(java.lang.String... items);
  public A removeAllFromNotPorts(Collection<String> items);
  public List<String> getNotPorts();
  public String getNotPort(int index);
  public String getFirstNotPort();
  public String getLastNotPort();
  public String getMatchingNotPort(Predicate<String> predicate);
  public Boolean hasMatchingNotPort(Predicate<String> predicate);
  public A withNotPorts(List<String> notPorts);
  public A withNotPorts(java.lang.String... notPorts);
  public Boolean hasNotPorts();
  public A addToPaths(int index,String item);
  public A setToPaths(int index,String item);
  public A addToPaths(java.lang.String... items);
  public A addAllToPaths(Collection<String> items);
  public A removeFromPaths(java.lang.String... items);
  public A removeAllFromPaths(Collection<String> items);
  public List<String> getPaths();
  public String getPath(int index);
  public String getFirstPath();
  public String getLastPath();
  public String getMatchingPath(Predicate<String> predicate);
  public Boolean hasMatchingPath(Predicate<String> predicate);
  public A withPaths(List<String> paths);
  public A withPaths(java.lang.String... paths);
  public Boolean hasPaths();
  public A addToPorts(int index,String item);
  public A setToPorts(int index,String item);
  public A addToPorts(java.lang.String... items);
  public A addAllToPorts(Collection<String> items);
  public A removeFromPorts(java.lang.String... items);
  public A removeAllFromPorts(Collection<String> items);
  public List<String> getPorts();
  public String getPort(int index);
  public String getFirstPort();
  public String getLastPort();
  public String getMatchingPort(Predicate<String> predicate);
  public Boolean hasMatchingPort(Predicate<String> predicate);
  public A withPorts(List<String> ports);
  public A withPorts(java.lang.String... ports);
  public Boolean hasPorts();
  
}
